package com.localmatters.shoal;

import com.sun.enterprise.ee.cms.core.CallBack;
import com.sun.enterprise.ee.cms.core.GMSConstants.shutdownType;
import com.sun.enterprise.ee.cms.core.GMSFactory;
import com.sun.enterprise.ee.cms.core.GroupManagementService;
import com.sun.enterprise.ee.cms.core.Signal;
import com.sun.enterprise.ee.cms.core.SignalAcquireException;
import com.sun.enterprise.ee.cms.core.SignalReleaseException;
import com.sun.enterprise.ee.cms.impl.client.FailureNotificationActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.FailureRecoveryActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.FailureSuspectedActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.GroupLeadershipNotificationActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.JoinNotificationActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.JoinedAndReadyNotificationActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.MessageActionFactoryImpl;
import com.sun.enterprise.ee.cms.impl.client.PlannedShutdownActionFactoryImpl;
import java.net.InetAddress;
import java.text.MessageFormat;
import javax.swing.DefaultListModel;
import javax.swing.JFrame;
import javax.swing.SwingWorker;

public class ShoalSample
    extends JFrame
    implements CallBack {

    private static final String GROUP_NAME = "LMI";
    private static final String COMPONENT_NAME = "SampleComponent";

    private DefaultListModel messagesListModel = new DefaultListModel();
    private GroupManagementService gms;

    public ShoalSample() {

        try {

            String serverName = InetAddress.getLocalHost().getCanonicalHostName();
            gms = (GroupManagementService) GMSFactory.startGMSModule(serverName, GROUP_NAME, GroupManagementService.MemberType.CORE, null);

            gms.addActionFactory(new FailureNotificationActionFactoryImpl(this));
            gms.addActionFactory(new FailureSuspectedActionFactoryImpl(this));
            gms.addActionFactory(new GroupLeadershipNotificationActionFactoryImpl(this));
            gms.addActionFactory(new JoinNotificationActionFactoryImpl(this));
            gms.addActionFactory(new JoinedAndReadyNotificationActionFactoryImpl(this));
            gms.addActionFactory(new MessageActionFactoryImpl(this), COMPONENT_NAME);
            gms.addActionFactory(new PlannedShutdownActionFactoryImpl(this));
            gms.addActionFactory(COMPONENT_NAME, new FailureRecoveryActionFactoryImpl(this));

            initComponents();

        } catch (Exception ex) {
            ex.printStackTrace();
        }
        
    }

    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        joinButton = new javax.swing.JButton();
        shutdownButton = new javax.swing.JButton();
        messageLabel = new javax.swing.JLabel();
        sendMessageButton = new javax.swing.JButton();
        messageTextField = new javax.swing.JTextField();
        messagesScrollPane = new javax.swing.JScrollPane();
        messagesList = new javax.swing.JList();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);

        joinButton.setText("Join");
        joinButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                joinButtonActionPerformed(evt);
            }
        });

        shutdownButton.setText("Shutdown");
        shutdownButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                shutdownButtonActionPerformed(evt);
            }
        });

        messageLabel.setText("Message");

        sendMessageButton.setText("Send Message");
        sendMessageButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                sendMessageButtonActionPerformed(evt);
            }
        });

        messageTextField.setText("Hello");

        messagesScrollPane.setViewportView(messagesList);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(messageLabel))
                    .addGroup(layout.createSequentialGroup()
                        .addContainerGap(129, Short.MAX_VALUE)
                        .addComponent(joinButton)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(shutdownButton)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(sendMessageButton))
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, layout.createSequentialGroup()
                        .addContainerGap()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(messagesScrollPane, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 447, Short.MAX_VALUE)
                            .addComponent(messageTextField, javax.swing.GroupLayout.DEFAULT_SIZE, 447, Short.MAX_VALUE))))
                .addContainerGap())
        );

        layout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {joinButton, sendMessageButton, shutdownButton});

        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(messageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(messageTextField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(sendMessageButton)
                    .addComponent(shutdownButton)
                    .addComponent(joinButton))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(messagesScrollPane, javax.swing.GroupLayout.PREFERRED_SIZE, 220, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void joinButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_joinButtonActionPerformed

        SwingWorker worker = new SwingWorker() {

            @Override
            protected Object doInBackground()
            throws Exception {
                GroupManagementService gms = GMSFactory.getGMSModule(GROUP_NAME);
                gms.join();
                return null;
            }

        };

        worker.execute();

    }//GEN-LAST:event_joinButtonActionPerformed

    private void shutdownButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_shutdownButtonActionPerformed

        SwingWorker worker = new SwingWorker() {

            @Override
            protected Object doInBackground()
            throws Exception {
                GroupManagementService gms = GMSFactory.getGMSModule(GROUP_NAME);
                gms.shutdown(shutdownType.INSTANCE_SHUTDOWN);
                return null;
            }

        };

        worker.execute();

    }//GEN-LAST:event_shutdownButtonActionPerformed

    private void sendMessageButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_sendMessageButtonActionPerformed

        SwingWorker worker = new SwingWorker() {

            @Override
            protected Object doInBackground()
            throws Exception {
                GMSFactory.getGMSModule(GROUP_NAME).getGroupHandle().sendMessage(null, messageTextField.getText().getBytes());
                return messageTextField.getText();
            }

            @Override
            protected void done() {
                try {
                    System.out.println("Sent message: " + get());
                } catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

        };

        worker.execute();

    }//GEN-LAST:event_sendMessageButtonActionPerformed

    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new ShoalSample().setVisible(true);
            }
        });
    }

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton joinButton;
    private javax.swing.JLabel messageLabel;
    private javax.swing.JTextField messageTextField;
    private javax.swing.JList messagesList;
    private javax.swing.JScrollPane messagesScrollPane;
    private javax.swing.JButton sendMessageButton;
    private javax.swing.JButton shutdownButton;
    // End of variables declaration//GEN-END:variables

    public void processNotification(Signal signal) {
        try {
            signal.acquire();
            System.out.println(MessageFormat.format("[{0},{1},{2}]", signal.getGroupName(), signal.getMemberToken(), signal.getClass()));
            signal.release();
        } catch (SignalAcquireException ex) {
            ex.printStackTrace();
        } catch (SignalReleaseException ex) {
            ex.printStackTrace();
        }
    }

}
